@@ -201,3 +201,28 @@ class SignalsHelper(object):
     def _print(message, force_print=False):
         if (settings.DEBUG or force_print) and getattr(settings, 'TEST_PRINT_TASKS', True):
             print(message)
+
+
+class temporary_disconnect_signal:
+    """ Temporarily disconnect a model from a signal """
+
+    def __init__(self, signal, receiver, sender, dispatch_uid=None):
+        self.signal = signal
+        self.receiver = receiver
+        self.sender = sender
+        self.dispatch_uid = dispatch_uid
+
+    def __enter__(self):
+        self.signal.disconnect(
+            receiver=self.receiver,
+            sender=self.sender,
+            dispatch_uid=self.dispatch_uid,
+        )
+
+    def __exit__(self, type, value, traceback):
+        self.signal.connect(
+            receiver=self.receiver,
+            sender=self.sender,
+            dispatch_uid=self.dispatch_uid,
+            weak=False
+        )
